@@ -1,6 +1,6 @@
 # apicrusher/core.py
 # Path: apicrusher/core.py
-# Version: 1.3.1 - Fixed indentation issues
+# Version: 1.4.0 - Model availability integration
 
 import hashlib
 import json
@@ -36,6 +36,14 @@ try:
 except ImportError:
     REDIS_AVAILABLE = False
 
+# Import model availability checker
+try:
+    from .model_availability import ModelAvailabilityChecker
+    MODEL_CHECKER_AVAILABLE = True
+except ImportError:
+    MODEL_CHECKER_AVAILABLE = False
+    print("⚠️ ModelAvailabilityChecker not found. Model fallback disabled.")
+
 class ContextCompressor:
     """Intelligent context compression to reduce API costs by 40-70%"""
     
@@ -683,6 +691,12 @@ class APIOptimizer:
         self.model_router = UniversalModelRouter()
         self.api_client = UniversalAPIClient(self.api_keys)
         
+        # Initialize model availability checker
+        if MODEL_CHECKER_AVAILABLE:
+            self.model_checker = ModelAvailabilityChecker()
+        else:
+            self.model_checker = None
+        
         # APICrusher configuration
         self.apicrusher_key = apicrusher_key
         self.rules = None
@@ -911,10 +925,18 @@ class APIOptimizer:
         return (tokens_in * config['cost_input'] + tokens_out * config['cost_output']) / 1000
     
     def complete(self, model: str, messages: List[Dict], **kwargs) -> Dict:
-        """Main completion method with universal optimization"""
+        """Main completion method with universal optimization and model availability checking"""
         
         start_time = time.time()
         
+        # Check model availability and get fallback if needed
+        if self.model_checker:
+            provider = self.model_router.detect_provider(model)
+            is_available, fallback = self.model_checker.is_model_available(provider, model)
+            if not is_available and fallback:
+                print(f"⚠️ Model {model} is deprecated/unavailable. Using {fallback}.")
+                model = fallback
+        
         # Calculate complexity
         complexity = self.calculate_complexity(messages)
         
@@ -1020,7 +1042,8 @@ class APIOptimizer:
                                 'cost_original': original_cost,
                                 'cost_optimized': optimized_cost,
                                 'savings': savings,
-                                'complexity': complexity
+                                'complexity': complexity,
+                                'model_available': True  # Track if fallback was used
                             },
                             timeout=2
                         )
@@ -1165,12 +1188,25 @@ class OpenAI:
                 model = kwargs.get('model', 'gpt-4o-mini')
                 messages = kwargs.get('messages', [])
                 
+                # Handle context compression parameters
+                compress_context = kwargs.pop('compress_context', False)
+                compression_threshold = kwargs.pop('compression_threshold', 10)
+                
                 # Remove our custom parameters before passing to API
                 api_kwargs = {k: v for k, v in kwargs.items() 
                              if k not in ['model', 'messages']}
                 
                 try:
-                    response = self.optimizer.complete(model, messages, **api_kwargs)
+                    # Use compression if requested
+                    if compress_context:
+                        response = self.optimizer.complete_with_compression(
+                            model, messages, 
+                            compress_context=compress_context,
+                            compression_threshold=compression_threshold,
+                            **api_kwargs
+                        )
+                    else:
+                        response = self.optimizer.complete(model, messages, **api_kwargs)
                     
                     # Return OpenAI-compatible response format
                     class CompletionResponse:
